==> dde-control-center_6.0.20.tar.xz: BUILD/translations/keyboard_language_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Africano</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>Amárico</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>Arábe</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>Asamés</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturiano</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Bielorruso</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Latín Bielorruso</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Búlgaro</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>Bengalí</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>Bengalí (India)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>Tibetano</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Bretón</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosnio</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Catalán</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Tártaro</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Checo</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Casubio</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Chuvasio</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Galés</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Danés</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>Butanés</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Griego</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>Inglés Británico</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>Ingles Americano</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estonio</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Vasco</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>Farsi</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Finés</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Feroés</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Francés</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Frisón</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Irlandés</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Escocés</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Gallego</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>Guyaratí</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Gaélico</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chatisgarí</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Croata</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Soraba</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Armenio</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesio</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Iñupiaq</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Islandés</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Esquimal</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>kazajo</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Groenlandés</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>Jemer</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>Canarés</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Cachemir - (Cachemira)</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>kurdo</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Córnico</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>kirguís</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Luxemburgués</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Limburgués</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Letón</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malgache</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Marshalés</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maorí</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Macedonio</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>Malabar</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongol</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>Maratí</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Malayo</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Maltés</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Birmano</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Nauruano</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Noruego (Escrito)</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Alemán bajo</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>Nepalí</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Holandés</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Noruego (Moderno)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation> Ndebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Sesotho sa leboa</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Occitano</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromo</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Osetio</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Panyabí</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>Pastún</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Portugués de Brasil</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Rumano</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>Sánscrito</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardo</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Sami septentrional</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>Cingalés</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Eslovaco</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Esloveno</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Somalí</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albanés</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Serbio</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>Serbio (Latín)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>Suazi</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Sesoto</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Suajili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>Telugú</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Tayiko</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>Tigriña</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turcomano</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Setsuana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turco</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tártaro</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>Uigur</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Uzbeko</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbeko (Cirílico)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Valón</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wólof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>Yidis</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>Chino simplificado</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Chino tradicional (RAE de Hong Kong, China)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Chino tradicional (Taiwan, China)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>Zulú</translation>
    </message>
</context>
</TS>

==> dde-control-center_6.0.45.tar.xz: BUILD/translations/keyboard_language_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Africano</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>Amárico</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>Arábe</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>Asamés</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturiano</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Bielorruso</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Latín Bielorruso</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Búlgaro</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>Bengalí</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>Bengalí (India)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>Tibetano</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Bretón</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosnio</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Catalán</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Tártaro</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Checo</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Casubio</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Chuvasio</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Galés</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Danés</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>Butanés</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Griego</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>Inglés Británico</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>Ingles Americano</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estonio</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Vasco</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>Farsi</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Finés</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Feroés</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Francés</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Frisón</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Irlandés</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Escocés</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Gallego</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>Guyaratí</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Gaélico</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chatisgarí</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Croata</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Soraba</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Armenio</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesio</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Iñupiaq</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Islandés</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Esquimal</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>kazajo</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Groenlandés</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>Jemer</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>Canarés</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Cachemir - (Cachemira)</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>kurdo</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Córnico</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>kirguís</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Luxemburgués</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Limburgués</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Letón</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malgache</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Marshalés</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maorí</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Macedonio</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>Malabar</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongol</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>Maratí</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Malayo</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Maltés</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Birmano</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Nauruano</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Noruego (Escrito)</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Alemán bajo</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>Nepalí</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Holandés</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Noruego (Moderno)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation> Ndebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Sesotho sa leboa</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Occitano</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromo</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Osetio</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Panyabí</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>Pastún</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Portugués de Brasil</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Rumano</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>Sánscrito</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardo</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Sami septentrional</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>Cingalés</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Eslovaco</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Esloveno</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Somalí</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albanés</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Serbio</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>Serbio (Latín)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>Suazi</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Sesoto</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Suajili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>Telugú</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Tayiko</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>Tigriña</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turcomano</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Setsuana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turco</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tártaro</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>Uigur</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Uzbeko</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbeko (Cirílico)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Valón</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wólof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>Yidis</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>Chino simplificado</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Chino tradicional (Hong Kong)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Chino tradicional (Hong Kong)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>Zulú</translation>
    </message>
</context>
</TS>
